summaryrefslogtreecommitdiffstats
path: root/lib/koproperty/property.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/koproperty/property.h')
-rw-r--r--lib/koproperty/property.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/lib/koproperty/property.h b/lib/koproperty/property.h
index 9f097c61..bc8a503e 100644
--- a/lib/koproperty/property.h
+++ b/lib/koproperty/property.h
@@ -104,7 +104,7 @@ enum PropertyType {
//predefined custom types
ValueFromList = 2000 /**<string value from a list*/,
- Symbol = 2001 /**<unicode symbol code*/,
+ Symbol = 2001 /**<tqunicode symbol code*/,
FontName /**<font name, e.g. "times new roman"*/,
FileURL /**<url of a file*/,
PictureFileURL /**<url of a pixmap*/,
@@ -306,9 +306,9 @@ class KOPROPERTY_EXPORT Property
/*! \return property icon's string. Can be empty. */
TQString icon() const;
- /*! \return a list of all children for this property, or NULL of there
- is no children for this property */
- const TQValueList<Property*>* children() const;
+ /*! \return a list of all tqchildren for this property, or NULL of there
+ is no tqchildren for this property */
+ const TQValueList<Property*>* tqchildren() const;
/*! \return a child property for \a name, or NULL if there is no property with that name. */
Property* child(const TQCString &name);
@@ -407,7 +407,7 @@ class KOPROPERTY_EXPORT Property
protected:
/*! Adds \a prop as a child of this property.
- The children will be owned by this property. */
+ The tqchildren will be owned by this property. */
void addChild(Property *prop);
/*! Adds \a set to this property. */